@@ -436,7 +436,7 @@ extractor_get_address (MetadataExtractor     *extractor,
 		address_uri = tracker_sparql_get_uuid_urn ();
 		address = tracker_resource_new (address_uri);
 
-		tracker_resource_set_string (address, "rdf:type", "nco:PostalAddress");
+		tracker_resource_set_uri (address, "rdf:type", "nco:PostalAddress");
 
 		if (sublocation) {
 			tracker_resource_set_string (address, "nco:region", sublocation);
@@ -844,16 +844,16 @@ extract_metadata (MetadataExtractor      *extractor,
 
 		geolocation = extractor_get_geolocation (extractor, extractor->tagcache);
 		if (geolocation) {
+			address = extractor_get_address (extractor, extractor->tagcache);
+			if (address) {
+				tracker_resource_set_relation (geolocation, "slo:postalAddress", address);
+				g_object_unref (address);
+			}
+
 			tracker_resource_set_relation (resource, "slo:location", geolocation);
 			g_object_unref (geolocation);
 		}
 
-		address = extractor_get_address (extractor, extractor->tagcache);
-		if (address) {
-			tracker_resource_set_relation (resource, "slo:postalAddress", address);
-			g_object_unref (address);
-		}
-
 		if (extractor->mime == EXTRACT_MIME_VIDEO) {
 			extractor_apply_video_metadata (extractor,
 			                                extractor->tagcache,
