@@ -35,14 +35,14 @@
 
 #include <glib.h>
 #include <glib/gstdio.h>
-#include <glib/poppler.h>
+#include <poppler.h>
 
 #include <gio/gunixoutputstream.h>
 #include <gio/gunixinputstream.h>
 
-#include <libtracker-common/tracker-date-time.h>
-#include <libtracker-common/tracker-utils.h>
-#include <libtracker-common/tracker-file-utils.h>
+#include <libtracker-miners-common/tracker-date-time.h>
+#include <libtracker-miners-common/tracker-utils.h>
+#include <libtracker-miners-common/tracker-file-utils.h>
 
 #include <libtracker-extract/tracker-extract.h>
 
